@@ -5,7 +5,7 @@
 from typing import (Callable, Dict, Generator, Iterable, Iterator, List, Mapping, Optional, Set,
                     TextIO, Tuple, TypeVar, Union, cast)
 
-from typing_extensions import ContextManager, Deque, Final, Literal, Type, overload
+from typing_extensions import ContextManager, Deque, Final, Literal, Type, final, overload
 
 T = TypeVar('T')
 Linesep = Literal['\n', '\r\n', '\r']
